@@ -85,7 +85,7 @@ acquire (gint nr)
   if (!g_rec_mutex_trylock (&locks[nr]))
     {
       if (g_test_verbose ())
-        g_print ("thread %p going to block on lock %d\n", self, nr);
+        g_printerr ("thread %p going to block on lock %d\n", self, nr);
 
       g_rec_mutex_lock (&locks[nr]);
     }
@@ -100,7 +100,7 @@ acquire (gint nr)
   g_assert (owners[nr] == self);   /* hopefully this is still us... */
 
   if (g_test_verbose ())
-    g_print ("thread %p recursively taking lock %d\n", self, nr);
+    g_printerr ("thread %p recursively taking lock %d\n", self, nr);
 
   g_rec_mutex_lock (&locks[nr]);  /* we're recursive, after all */
 
@@ -143,7 +143,7 @@ test_rec_mutex4 (void)
     g_rec_mutex_init (&locks[i]);
 
   for (i = 0; i < THREADS; i++)
-    threads[i] = g_thread_create (thread_func, NULL, TRUE, NULL);
+    threads[i] = g_thread_new ("test", thread_func, NULL);
 
   for (i = 0; i < THREADS; i++)
     g_thread_join (threads[i]);
@@ -203,7 +203,7 @@ test_mutex_perf (gconstpointer data)
   depth = c % 256;
 
   for (i = 0; i < n_threads - 1; i++)
-    threads[i] = g_thread_create (addition_thread, &x, TRUE, NULL);
+    threads[i] = g_thread_new ("test", addition_thread, &x);
 
   /* avoid measuring thread setup/teardown time */
   start_time = g_get_monotonic_time ();
